<?php

/** Copyright (c) 2004 Matthew Schwartz  <matt at mattschwartz dot net>
    Contributors:
      Dries Buytaert - code from taxonomy.module
      Ber Kessels
      Robrecht Jacques
    
    This file is a contributed module of Drupal.

    Drupal and this module are free software; you can redistribute this file
    and/or modify it under the terms of the GNU General Public License as 
    published by the Free Software Foundation; either version 2 of the License,
    or (at your option) any later version.

    This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file
 * Administrative pages.
 */

/******************************************************************
 * Menu callback: admin/content/copyright/add and
 * admin/content/copyright/edit.
 ******************************************************************/

function copyright_edit(&$form_state, $edit) {
  $form = array();

  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Copyright or license name'),
    '#default_value' => $edit['name'],
    '#maxlength' => 60,
    '#description' => t('Short name'),
    '#required' => TRUE,
  );
  $form['description'] = array(
    '#type' => 'textfield',
    '#title' => t('Description'),
    '#default_value' => $edit['description'],
    '#maxlength' => 255,
    '#description' => t('Longer description'),
  );
  $form['image_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Image URL'),
    '#default_value' => $edit['image_url'],
    '#maxlength' => 255,
    '#description' => t('URL (relative or absolute) to an image associated with this copyright or license. If provided it will automatically be displayed along with the copyright notice.'),
  );
  $form['source_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Source URL'),
    '#default_value' => $edit['source_url'],
    '#maxlength' => 255,
    '#description' => t('URL (relative or absolute) to the complete text or HTML of the copyright or license. To dynamically have a page created with the full license text below set a relative path without a leading backslash (e.g. "copyright").'),
  );
  $form['site_notice'] = array(
    '#type' => 'textarea',
    '#title' => t('Site notice'),
    '#default_value' => $edit['site_notice'],
    '#rows' => 5,
    '#description' => t('Notice displayed for entire site (in footer or block). HTML is allowed and variables include @year, @site and @source_url.'),
    '#required' => TRUE,
  );
  $form['node_notice'] = array(
    '#type' => 'textarea',
    '#title' => t('Node notice'),
    '#default_value' => $edit['node_notice'],
    '#rows' => 5,
    '#description' => t('Notice displayed for nodes which are not using the site default. HTML is allowed and variables include @year, @author, @site and @source_url.'),
    '#required' => TRUE,
  );
  $form['license'] = array(
    '#type' => 'textarea',
    '#title' => t('Full copyright or license'),
    '#default_value' => $edit['license'],
    '#rows' => 20,
    '#description' => t('The complete text or HTML of the copyright or license. Leave empty to use Source URL (above).'),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#submit' => array('copyright_edit_submit_save'),
  );
  if ($edit['cpyid']) {
    $form['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#submit' => array('copyright_edit_submit_delete'),
      '#disabled' => (variable_get('copyright-default', 1) == $edit['cpyid']),
    );
    $form['cpyid'] = array(
      '#type' => 'hidden',
      '#value' => $edit['cpyid'],
    );
  }

  return $form;
}

function copyright_edit_submit_save($form, $form_state) {
  $goto = 'admin/content/copyright/list';

  if (isset($form_state['values']['cpyid'])) {
    $cpyid = $form_state['values']['cpyid'];
    _copyright_db_update_copyright($form_state['values']);
    module_invoke_all('copyright', 'update', 'license', $form_state['values']);
    drupal_set_message(t('Updated copyright %name.', array('%name' => $form_state['values']['name'])));
  }
  else {
    $form_state['values']['cpyid'] = _copyright_db_insert_copyright($form_values);
    module_invoke_all('copyright', 'insert', 'license', $form_state['values']);
    drupal_set_message(t('Created new copyright %name.', array('%name' => $form_values['name'])));
  }
  cache_clear_all();
  $form_state['redirect'] = 'admin/content/copyright/list';
}

/******************************************************************
 * Menu callback: admin/content/copyright/delete.
 ******************************************************************/

function copyright_admin_delete($cpyid) {
  if (user_access('administer copyright')) {
    if (is_numeric($cpyid) && $license = copyright_get_license($cpyid)) {
      if (variable_get('copyright-default', 1) == $cpyid) {
        return t('You can not delete the "%name" copyright because it is currently configured as the site-wide default copyright. Go to the <a href="@overview-url">copyright overview page</a> to change the site-wide default copyright first and then delete this copyright.', array('%name' => $license->name, '@overview-url' => url('admin/content/copyright/list')));
      }
      else {
        $form = array();
        $form['cpyid'] = array(
          '#type' => 'value',
          '#value' => $cpyid,
        );
        $form['license'] = array(
          '#type' => 'value',
          '#value' => $license,
        );
        return confirm_form($form, t('Are you sure you want to delete %title?', array('%title' => $license->name)), $_GET['destination'] ? $_GET['destination'] : 'admin/content/copyright/list', t('This will reset all nodes using this copyright back to the site default. This action cannot be undone.'), t('Delete'), t('Cancel'));
      }
    }
    return drupal_not_found();
  }
  return drupal_access_denied();
}

function copyright_admin_delete_submit($form_id, $form_values) {
  if ($form_values['confirm']) {
    $license = $form_values['license'];
    db_query("DELETE FROM {copyrights} WHERE cpyid = %d", $license->cpyid);
    db_query("DELETE FROM {copyright_node} WHERE cpyid = %d", $license->cpyid);
    cache_clear_all();
    drupal_set_message(t('Deleted copyright "%name". All nodes set to that copyright have been set back to the site default.', array('%name' => $license->name)));
  }
  return 'admin/content/copyright/list';
}

/******************************************************************
 * Menu callback: admin/content/copyright/list.
 ******************************************************************/

function copyright_admin_overview() {
  $form = array();
  $options = array();

  $default = variable_get('copyright-default', 1);

  foreach (copyright_get_licenses() as $license) {
    $options[$license->cpyid] = $license->name;

    $form[$license->name] = array(
      '#type' => 'item',
      '#title' => $license->name,
      '#description' => $license->description,
    );

    $form[$license->name]['cpyid'] = array(
      '#type' => 'hidden',
      '#value' => $license->cpyid,
    );

    $operations = l(t('edit'), 'admin/content/copyright/edit/'. $license->cpyid);
    if ($license->cpyid != $default) {
      $operations .= ' '. l(t('delete'), 'admin/content/copyright/delete/'. $license->cpyid);
    }
    $form[$license->name]['operations'] = array(
      '#value' => $operations,
    );
  }

  $form['default'] = array(
    '#type' => 'radios',
    '#options' => $options,
    '#default_value' => variable_get('copyright-default', 1),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Set default copyright'),
  );

  return $form;
}

function copyright_admin_overview_submit($form_id, $form_values) {
  if (is_numeric($form_values['default'])) {
    drupal_set_message(t('Default site-wide copyright updated.'));
    variable_set('copyright-default', $form_values['default']);
  }
}

function theme_copyright_admin_overview($form) {
  $rows = array();
  foreach (element_children($form) as $name) {
    $element = $form[$name];
    if (isset($element['operations'])) {
      $form['default'][$element['cpyid']['#value']]['#title'] = '';
      $rows[] = array(
        drupal_render($form['default'][$element['cpyid']['#value']]),
        check_plain($name),
        drupal_render($element['operations']),
      );
      unset($form[$name]);
    }
  }
  $header = array(t('Default'), t('Name'), t('Operations'));
  $output = theme('table', $header, $rows);
  $output .= drupal_render($form);
  return $output;
}

